@@ -1079,7 +1079,12 @@ void remmina_main_reload_preferences()
 	GtkSettings *settings;
 	settings = gtk_settings_get_default();
 	g_object_set(settings, "gtk-application-prefer-dark-theme", remmina_pref.dark_theme, NULL);
-	remmina_main_on_action_search_toggle(NULL,NULL,NULL);
+	if(remmina_pref.hide_searchbar){
+		gtk_toggle_button_set_active(remminamain->search_toggle, FALSE);
+	}
+	else{
+		gtk_toggle_button_set_active(remminamain->search_toggle, TRUE);
+	}
 	gtk_tree_view_column_set_visible(remminamain->column_files_list_notes, remmina_pref.always_show_notes);
 }
 
@@ -1105,8 +1110,6 @@ void remmina_main_on_action_application_preferences(GSimpleAction *action, GVari
 	GtkWidget *widget = remmina_pref_dialog_new(tab_num, remminamain->window);
 
 	gtk_widget_show_all(widget);	
-	/* Reload to use new preferences */
-	remmina_main_reload_preferences();
 }
 
 void remmina_main_on_action_application_default(GSimpleAction *action, GVariant *param, gpointer data)
@@ -1155,6 +1158,24 @@ void remmina_main_on_date_column_sort_clicked()
 	}
 }
 
+void remmina_main_toggle_password_view(GtkWidget *widget, gpointer data)
+{
+	GtkWindow *mainwindow;
+	gboolean visible = gtk_entry_get_visibility(GTK_ENTRY(widget));
+
+	mainwindow = remmina_main_get_window();
+	if (remmina_pref_get_boolean("use_primary_password") && remmina_pref_get_boolean("lock_view_passwords") && remmina_unlock_new(mainwindow) == 0)
+		return;
+
+	if (visible) {
+		gtk_entry_set_visibility(GTK_ENTRY(widget), FALSE);
+		gtk_entry_set_icon_from_icon_name(GTK_ENTRY(widget), GTK_ENTRY_ICON_SECONDARY, "org.remmina.Remmina-password-reveal-symbolic");
+	} else {
+		gtk_entry_set_visibility(GTK_ENTRY(widget), TRUE);
+		gtk_entry_set_icon_from_icon_name(GTK_ENTRY(widget), GTK_ENTRY_ICON_SECONDARY, "org.remmina.Remmina-password-conceal-symbolic");
+	}
+}
+
 static void remmina_main_import_file_list(GSList *files)
 {
 	TRACE_CALL(__func__);
@@ -1400,7 +1421,6 @@ void remmina_main_on_action_search_toggle(GSimpleAction *action, GVariant *param
 {
 	TRACE_CALL(__func__);
 	REMMINA_DEBUG("Search toggle triggered");
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(remminamain->search_toggle), !remmina_pref.hide_searchbar);
 
 	gboolean toggle_status = gtk_toggle_button_get_active(remminamain->search_toggle);
 
